git: 61cf9cb8cb85 - 2026Q2 - www/iridium: update to 2026.04.147
- Go to: [ bottom of page ] [ top of archives ] [ this month ]
Date: Thu, 16 Apr 2026 06:43:46 UTC
The branch 2026Q2 has been updated by rnagy:
URL: https://cgit.FreeBSD.org/ports/commit/?id=61cf9cb8cb855ff2ee2d16f500066a832e43de54
commit 61cf9cb8cb855ff2ee2d16f500066a832e43de54
Author: Robert Nagy <rnagy@FreeBSD.org>
AuthorDate: 2026-04-15 12:14:25 +0000
Commit: Robert Nagy <rnagy@FreeBSD.org>
CommitDate: 2026-04-16 06:43:32 +0000
www/iridium: update to 2026.04.147
(cherry picked from commit a99dfec458192515430447fac4942100835e6a47)
---
www/iridium/Makefile | 2 +-
www/iridium/distinfo | 6 +-
www/iridium/files/patch-base_BUILD.gn | 16 +-
...cator_partition__allocator_partition__alloc.gni | 4 +-
...tition__allocator_src_partition__alloc_BUILD.gn | 4 +-
...artition__alloc_address__space__randomization.h | 4 +-
...locator_src_partition__alloc_partition__root.cc | 6 +-
.../files/patch-base_files_file__util__unittest.cc | 4 +-
...-base_memory_platform__shared__memory__region.h | 6 +-
.../files/patch-base_threading_platform__thread.h | 4 +-
...ch-base_threading_platform__thread__unittest.cc | 8 +-
...tch-base_trace__event_malloc__dump__provider.cc | 8 +-
...atch-base_trace__event_memory__dump__manager.cc | 4 +-
.../files/patch-build_config_clang_BUILD.gn | 4 +-
.../files/patch-build_config_compiler_BUILD.gn | 26 +--
.../files/patch-build_dotfile__settings.gni | 4 +-
www/iridium/files/patch-build_rust_std_BUILD.gn | 4 +-
www/iridium/files/patch-cc_base_features.cc | 4 +-
.../patch-chrome_app_chrome__main__delegate.cc | 35 ++--
www/iridium/files/patch-chrome_browser_BUILD.gn | 4 +-
.../files/patch-chrome_browser_about__flags.cc | 194 ++++++++++++---------
...kground_extensions_background__mode__manager.cc | 4 +-
...e_browser_background_glic_glic__status__icon.cc | 26 +--
.../patch-chrome_browser_browser__process__impl.cc | 8 +-
...hrome_browser_chrome__browser__field__trials.cc | 21 ++-
...r_chrome__browser__interface__binders__webui.cc | 8 +-
...r__interface__binders__webui__parts__desktop.cc | 12 +-
.../patch-chrome_browser_chrome__browser__main.cc | 38 ++--
...-chrome_browser_chrome__browser__main__linux.cc | 4 +-
...ome_browser_chrome__content__browser__client.cc | 42 ++---
...rome_browser_chrome__content__browser__client.h | 4 +-
...tent__browser__client__navigation__throttles.cc | 6 +-
...rome_browser_component__updater_registration.cc | 8 +-
www/iridium/files/patch-chrome_browser_defaults.cc | 4 +-
...se_browser__management_management__identity.cc} | 8 +-
...reporting_cloud__profile__reporting__service.cc | 20 +++
.../files/patch-chrome_browser_extensions_BUILD.gn | 4 +-
...ate_chrome__desktop__report__request__helper.cc | 8 +-
...__private_passwords__private__delegate__impl.cc | 4 +-
...s_api_runtime_chrome__runtime__api__delegate.cc | 4 +-
...extensions_api_settings__private_prefs__util.cc | 8 +-
...chrome_browser_extensions_api_tabs_tabs__api.cc | 4 +-
...gging__private_webrtc__logging__private__api.cc | 4 +-
...api_webstore__private_webstore__private__api.cc | 4 +-
...k_system__logs_chrome__system__logs__fetcher.cc | 6 +-
.../patch-chrome_browser_flag__descriptions.h | 4 +-
...chrome_browser_glic_host_glic__page__handler.cc | 4 +-
.../files/patch-chrome_browser_global__features.cc | 12 +-
.../files/patch-chrome_browser_global__features.h | 8 +-
...er_discovery_discovery__network__list__posix.cc | 4 +-
...media_webrtc_rtc__diagnostic__logging__utils.cc | 11 ++
...ser_media_webrtc_webrtc__logging__controller.cc | 10 +-
...wser_media_webrtc_webrtc__logging__controller.h | 10 +-
...chrome__browser__main__extra__parts__metrics.cc | 10 +-
...ser_metrics_chrome__metrics__service__client.cc | 42 +++--
...trics_power_process__metrics__recorder__util.cc | 4 +-
...hrome_browser_metrics_power_process__monitor.cc | 8 +-
...chrome_browser_metrics_power_process__monitor.h | 4 +-
...owser_net_profile__network__context__service.cc | 6 +-
..._browser_new__tab__page_new__tab__page__util.cc | 4 +-
...cations_notification__display__service__impl.cc | 8 +-
...oad__metrics_page__load__metrics__initialize.cc | 4 +-
...d__manager_chrome__password__manager__client.cc | 10 +-
...wser__cloud__management__controller__desktop.cc | 8 +-
...onfiguration__policy__handler__list__factory.cc | 61 ++++---
.../patch-chrome_browser_prefs_browser__prefs.cc | 14 +-
...hrome__browser__main__extra__parts__profiles.cc | 49 +++---
...ies_regional__capabilities__service__factory.cc | 21 ++-
...ties_regional__capabilities__service__factory.h | 11 ++
...r__context__menu_render__view__context__menu.cc | 6 +-
...owsing_chrome__password__protection__service.cc | 4 +-
...tch-chrome_browser_sessions_session__restore.cc | 6 +-
...ser_sharing_sharing__handler__registry__impl.cc | 6 +-
...tch-chrome_browser_signin_signin__hats__util.cc | 8 +-
...h-chrome_browser_sync_sync__service__factory.cc | 6 +-
.../patch-chrome_browser_themes_theme__helper.cc | 4 +-
.../patch-chrome_browser_themes_theme__service.cc | 8 +-
...-chrome_browser_ui_actions_chrome__action__id.h | 4 +-
...rome_browser_ui_browser__command__controller.cc | 18 +-
.../patch-chrome_browser_ui_browser__commands.cc | 4 +-
.../patch-chrome_browser_ui_browser__ui__prefs.cc | 8 +-
...r__window_internal_browser__window__features.cc | 10 +-
...wser__window_public_browser__window__features.h | 8 +-
.../files/patch-chrome_browser_ui_chrome__pages.cc | 10 +-
.../files/patch-chrome_browser_ui_chrome__pages.h | 6 +-
.../patch-chrome_browser_ui_hats_survey__config.cc | 4 +-
...r_ui_omnibox_omnibox__pedal__implementations.cc | 4 +-
...rollers_relaunch__chrome__bubble__controller.cc | 6 +-
..._passwords_manage__passwords__ui__controller.cc | 6 +-
...h-chrome_browser_ui_prefs_prefs__tab__helper.cc | 11 +-
...chrome_browser_ui_startup_bad__flags__prompt.cc | 4 +-
...browser_ui_startup_startup__browser__creator.cc | 8 +-
...r_ui_startup_startup__browser__creator__impl.cc | 24 +--
...me_browser_ui_startup_startup__tab__provider.cc | 4 +-
.../files/patch-chrome_browser_ui_tab__helpers.cc | 6 +-
...h-chrome_browser_ui_tabs_public_tab__features.h | 10 +-
.../patch-chrome_browser_ui_tabs_tab__features.cc | 25 ++-
...tch-chrome_browser_ui_tabs_tab__strip__prefs.cc | 4 +-
...ui_task__manager_task__manager__table__model.cc | 10 +-
.../files/patch-chrome_browser_ui_ui__features.cc | 16 +-
.../files/patch-chrome_browser_ui_ui__features.h | 12 +-
.../files/patch-chrome_browser_ui_url__identity.cc | 6 +-
...s_chrome__browser__main__extra__parts__views.cc | 6 +-
...collaboration__controller__delegate__desktop.cc | 4 +-
...r_ui_views_frame_browser__frame__view__linux.cc | 6 +-
...-chrome_browser_ui_views_frame_browser__view.cc | 8 +-
...r_ui_views_frame_custom__corners__background.cc | 11 --
...rame_layout_browser__view__app__layout__impl.cc | 4 +-
..._ui_views_frame_opaque__browser__frame__view.cc | 10 +-
..._ui_views_frame_system__menu__model__builder.cc | 8 +-
...ui_views_frame_system__menu__model__delegate.cc | 8 +-
...r_ui_views_location__bar_location__bar__view.cc | 4 +-
...views_passwords_password__bubble__view__base.cc | 6 +-
...er_ui_views_profiles_avatar__toolbar__button.cc | 4 +-
...ser_ui_views_profiles_avatar__toolbar__button.h | 4 +-
..._views_profiles_first__run__flow__controller.cc | 20 +++
...ui_views_profiles_profile__menu__coordinator.cc | 4 +-
...ui_views_tabs_dragging_tab__drag__controller.cc | 8 +-
...cts_projects__panel__tab__groups__item__view.cc | 11 ++
...projects_projects__panel__thread__item__view.cc | 11 ++
.../patch-chrome_browser_ui_views_tabs_tab.cc | 4 +-
...ui_views_tabs_tab__hover__card__bubble__view.cc | 4 +-
...rome_browser_ui_views_tabs_tab__style__views.cc | 6 +-
..._vertical_vertical__tab__group__header__view.cc | 11 ++
...hrome_browser_ui_views_toolbar_toolbar__view.cc | 11 ++
..._education_browser__user__education__service.cc | 6 +-
...eb__apps_web__app__integration__test__driver.cc | 20 +--
...i_web__applications_app__browser__controller.cc | 4 +-
...eb__applications_web__app__ui__manager__impl.cc | 6 +-
...web__applications_web__app__ui__manager__impl.h | 4 +-
...atch-chrome_browser_ui_webui_about_about__ui.cc | 4 +-
...icate__manager_certificate__manager__handler.cc | 4 +-
...me_browser_ui_webui_chrome__web__ui__configs.cc | 14 +-
...i_webui_chrome__web__ui__controller__factory.cc | 10 +-
...ternals_connectors__internals__page__handler.cc | 8 +-
...i_connectors__internals_device__trust__utils.cc | 12 +-
..._cr__components_searchbox_searchbox__handler.cc | 8 +-
...e_browser_ui_webui_management_management__ui.cc | 4 +-
..._ui_webui_management_management__ui__handler.cc | 10 +-
...rowser_ui_webui_settings_appearance__handler.cc | 4 +-
...tings_settings__localized__strings__provider.cc | 20 +--
...ser_ui_webui_signin_profile__picker__handler.cc | 4 +-
...r_upgrade__detector_version__history__client.cc | 4 +-
...ications_extensions_extension__status__utils.cc | 4 +-
...ons_os__integration_os__integration__manager.cc | 4 +-
...integration_run__on__os__login__sub__manager.cc | 4 +-
...pplications_policy_web__app__policy__manager.cc | 4 +-
...s_test_os__integration__test__override__impl.cc | 32 ++--
...ch-chrome_browser_web__applications_web__app.cc | 6 +-
..._browser_web__applications_web__app__helpers.cc | 4 +-
...thn_chrome__authenticator__request__delegate.cc | 4 +-
...tch-chrome_browser_webauthn_enclave__manager.cc | 6 +-
.../files/patch-chrome_common_chrome__features.cc | 10 +-
.../files/patch-chrome_common_chrome__features.h | 10 +-
.../files/patch-chrome_common_chrome__switches.cc | 6 +-
.../files/patch-chrome_common_chrome__switches.h | 6 +-
...hrome_common_extensions_extension__constants.cc | 11 --
...chrome_common_extensions_extension__constants.h | 13 +-
.../files/patch-chrome_common_pref__names.h | 24 +--
.../files/patch-chrome_common_url__constants.h | 8 +-
.../patch-chrome_common_webui__url__constants.cc | 8 +-
.../patch-chrome_common_webui__url__constants.h | 8 +-
...e_renderer_chrome__content__renderer__client.cc | 6 +-
...rome_test_chromedriver_chrome_chrome__finder.cc | 8 +-
www/iridium/files/patch-components_BUILD.gn | 12 +-
...owser_foundations_browser__autofill__manager.cc | 4 +-
...autofill_core_browser_payments_bnpl__manager.cc | 4 +-
...ill_core_common_autofill__payments__features.cc | 24 ++-
...onents_commerce_core_commerce__feature__list.cc | 6 +-
.../files/patch-components_crash_core_app_BUILD.gn | 10 +-
...nents_device__signals_test_signals__contract.cc | 4 +-
...ts_enterprise_browser_reporting_report__util.cc | 4 +-
...ctors_core_realtime__reporting__client__base.cc | 6 +-
...e__engagement_public_feature__configurations.cc | 4 +-
...eature__engagement_public_feature__constants.cc | 6 +-
...feature__engagement_public_feature__constants.h | 6 +-
...nts_feature__engagement_public_feature__list.cc | 8 +-
...ents_feature__engagement_public_feature__list.h | 14 +-
...n_providers_cast_channel_cast__message__util.cc | 4 +-
...ter_common_providers_cast_channel_enum__table.h | 6 +-
...zation__guide_core_optimization__guide__util.cc | 11 +-
...ger_core_browser_features_password__features.cc | 8 +-
...ager_core_browser_features_password__features.h | 8 +-
...ger_core_browser_password__autofill__manager.cc | 6 +-
...manager_core_browser_password__form__manager.cc | 6 +-
...core_browser_password__store_login__database.cc | 6 +-
...capabilities_regional__capabilities__service.cc | 11 ++
..._capabilities_regional__capabilities__service.h | 11 ++
...nents_search__engines_template__url__service.cc | 4 +-
...ervices_font__data_font__data__service__impl.cc | 10 +-
...mponents_signin_public_base_signin__switches.cc | 53 ++++--
...omponents_signin_public_base_signin__switches.h | 41 ++++-
...onents_supervised__user_core_common_features.cc | 19 +-
.../patch-components_sync_service_sync__prefs.cc | 4 +-
...nts_user__education_views_help__bubble__view.cc | 6 +-
...isplay__embedder_skia__output__surface__impl.cc | 4 +-
..._display__embedder_software__output__surface.cc | 4 +-
...omponents_viz_service_display_skia__renderer.cc | 4 +-
...components_viz_service_gl_gpu__service__impl.cc | 6 +-
...-components_viz_service_gl_gpu__service__impl.h | 4 +-
...atch-content_app_content__main__runner__impl.cc | 15 +-
www/iridium/files/patch-content_browser_BUILD.gn | 16 +-
..._browser_browser__child__process__host__impl.cc | 4 +-
...t_browser_browser__child__process__host__impl.h | 4 +-
.../patch-content_browser_browser__main__loop.cc | 8 +-
...ent_browser_network__service__instance__impl.cc | 10 +-
...rowser_renderer__host_delegated__frame__host.cc | 14 +-
...r_renderer__host_render__process__host__impl.cc | 14 +-
...er_renderer__host_render__process__host__impl.h | 8 +-
...der__process__host__impl__receiver__bindings.cc | 24 +--
...derer__host_render__widget__host__view__aura.cc | 10 +-
...browser_service__host_utility__process__host.cc | 6 +-
.../patch-content_browser_v8__snapshot__files.cc | 4 +-
...browser_webui_web__ui__main__frame__observer.cc | 4 +-
www/iridium/files/patch-content_child_BUILD.gn | 4 +-
www/iridium/files/patch-content_common_BUILD.gn | 4 +-
www/iridium/files/patch-content_common_features.cc | 30 ++--
www/iridium/files/patch-content_common_features.h | 20 ++-
...tent_public_browser_content__browser__client.cc | 4 +-
...atch-content_public_common_content__features.cc | 8 +-
...atch-content_public_common_content__switches.cc | 6 +-
...patch-content_public_common_content__switches.h | 6 +-
.../patch-content_renderer_render__thread__impl.cc | 10 +-
...ent_renderer_renderer__blink__platform__impl.cc | 10 +-
.../files/patch-content_renderer_renderer__main.cc | 4 +-
www/iridium/files/patch-content_shell_BUILD.gn | 4 +-
..._browser__context__keyed__service__factories.cc | 4 +-
...sions_browser_api_messaging_message__service.cc | 10 +-
...tensions_common_api___permission__features.json | 33 +---
...ensions_renderer_bindings_api__binding__util.cc | 4 +-
...ns_shell_browser_shell__browser__main__parts.cc | 4 +-
...buffer_client_test__shared__image__interface.cc | 6 +-
...mand__buffer_service_dawn__context__provider.cc | 4 +-
..._command__buffer_service_gles2__cmd__decoder.cc | 4 +-
...mmand__buffer_service_shared__context__state.cc | 6 +-
...ommand__buffer_service_shared__context__state.h | 4 +-
...image_angle__vulkan__image__backing__factory.cc | 8 +-
...e_shared__image_external__vk__image__backing.cc | 6 +-
...service_shared__image_shared__image__factory.cc | 12 +-
...service_shared__image_shared__image__manager.cc | 4 +-
.../files/patch-gpu_config_gpu__finch__features.cc | 4 +-
.../files/patch-gpu_config_gpu__finch__features.h | 4 +-
.../files/patch-gpu_config_gpu__info__collector.cc | 4 +-
.../files/patch-gpu_ipc_service_gpu__init.cc | 16 +-
www/iridium/files/patch-headless_BUILD.gn | 4 +-
...b_browser_headless__content__browser__client.cc | 4 +-
www/iridium/files/patch-ipc_param__traits__utils.h | 4 +-
www/iridium/files/patch-media_audio_BUILD.gn | 4 +-
.../files/patch-media_base_media__switches.cc | 38 ++--
.../files/patch-media_base_media__switches.h | 10 +-
www/iridium/files/patch-media_base_video__frame.cc | 8 +-
...h-media_capture_video_linux_fake__v4l2__impl.cc | 4 +-
..._capture_video_linux_v4l2__capture__delegate.cc | 32 ++--
..._linux_video__capture__device__factory__v4l2.cc | 16 +-
...capture_video_video__capture__device__client.cc | 4 +-
...a_gpu_chromeos_gl__image__processor__backend.cc | 4 +-
...pu_chromeos_mailbox__video__frame__converter.cc | 4 +-
...a_gpu_chromeos_platform__video__frame__utils.cc | 14 +-
www/iridium/files/patch-media_webrtc_helpers.cc | 4 +-
.../files/patch-mojo_core_channel__posix.cc | 4 +-
www/iridium/files/patch-net_BUILD.gn | 18 +-
www/iridium/files/patch-net_base_features.cc | 17 +-
www/iridium/files/patch-net_dns_BUILD.gn | 10 +-
.../patch-net_http_http__auth__gssapi__posix.cc | 4 +-
.../files/patch-net_socket_tcp__socket__posix.cc | 4 +-
.../files/patch-net_socket_udp__socket__posix.cc | 48 ++++-
.../patch-net_socket_udp__socket__unittest.cc | 12 +-
...ets_websocket__basic__stream__adapters__test.cc | 4 +-
.../files/patch-pdf_pdfium_pdfium__engine.cc | 4 +-
www/iridium/files/patch-remoting_base_branding.cc | 35 ++++
www/iridium/files/patch-remoting_base_username.cc | 11 ++
www/iridium/files/patch-remoting_base_username.h | 11 ++
.../files/patch-remoting_host_base_switches.cc | 7 +-
.../files/patch-remoting_host_base_switches.h | 7 +-
.../patch-remoting_host_desktop__process__main.cc | 20 +++
...tch-remoting_host_desktop__session__connector.h | 8 +-
.../files/patch-remoting_host_host__main.cc | 16 +-
.../files/patch-remoting_host_ipc__constants.h | 4 +-
...patch-remoting_host_ipc__desktop__environment.h | 11 ++
.../files/patch-remoting_host_it2me_it2me__host.cc | 4 +-
.../patch-remoting_host_remoting__me2me__host.cc | 44 ++---
...atch-remoting_protocol_webrtc__video__stream.cc | 8 +-
...-services_device_public_cpp_device__features.cc | 9 +-
...h-services_device_public_cpp_device__features.h | 9 +-
www/iridium/files/patch-services_network_BUILD.gn | 4 +-
.../patch-services_network_network__context.cc | 6 +-
.../patch-services_network_network__context.h | 4 +-
.../patch-services_network_network__service.cc | 6 +-
.../patch-services_network_network__service.h | 8 +-
.../patch-services_network_public_cpp_BUILD.gn | 4 +-
.../patch-services_network_public_mojom_BUILD.gn | 6 +-
.../patch-skia_ext_SkMemory__new__handler.cpp | 6 +-
.../files/patch-third__party_angle_BUILD.gn | 8 +-
.../patch-third__party_blink_common_features.cc | 6 +-
...blink_renderer_controller_blink__initializer.cc | 8 +-
...blink_renderer_core_exported_web__view__impl.cc | 8 +-
...arty_blink_renderer_core_layout_layout__view.cc | 4 +-
...r_core_origin__trials_origin__trial__context.cc | 4 +-
...party_blink_renderer_core_paint_paint__layer.cc | 4 +-
...odules_webaudio_audio__worklet__thread__test.cc | 4 +-
...odules_webgl_webgl__rendering__context__base.cc | 20 +--
...rty_blink_renderer_modules_webgpu_gpu__queue.cc | 4 +-
...h-third__party_blink_renderer_platform_BUILD.gn | 4 +-
...rer_platform_graphics_begin__frame__provider.cc | 4 +-
...platform_graphics_canvas__resource__provider.cc | 4 +-
...r_platform_graphics_gpu_image__layer__bridge.cc | 8 +-
...derer_platform_runtime__enabled__features.json5 | 41 ++---
...renderer_platform_text_text__break__iterator.cc | 13 --
.../patch-third__party_brotli_common_platform.h | 11 --
.../files/patch-third__party_ffmpeg_configure | 4 +-
...onfig_linux_arm64-cpu-detect_config_av1__rtcd.h | 6 +-
...arty_pdfium_core_fxge_linux_fx__linux__impl.cpp | 4 +-
.../files/patch-third__party_pdfium_pdfium.gni | 6 +-
...-third__party_perfetto_src_base_unix__socket.cc | 6 +-
...__party_speech-dispatcher_libspeechd__version.h | 4 +-
...d__party_sqlite_src_amalgamation__dev_sqlite3.c | 4 +-
...-third__party_sqlite_src_amalgamation_sqlite3.c | 8 +-
.../files/patch-third__party_webrtc_BUILD.gn | 4 +-
...tch-third__party_webrtc_rtc__base_byte__order.h | 4 +-
...ty_webrtc_rtc__base_physical__socket__server.cc | 22 +--
...ch-tools_perf_chrome__telemetry__build_BUILD.gn | 4 +-
...atch-tools_variations_fieldtrial__to__struct.py | 4 +-
...tch-ui_accessibility_accessibility__features.cc | 6 +-
...atch-ui_accessibility_accessibility__features.h | 6 +-
.../files/patch-ui_base_clipboard_clipboard.cc | 4 +-
...tch-ui_base_clipboard_clipboard__non__backed.cc | 4 +-
.../files/patch-ui_base_test_ui__controls.h | 4 +-
.../files/patch-ui_compositor_compositor.cc | 4 +-
www/iridium/files/patch-ui_compositor_compositor.h | 4 +-
www/iridium/files/patch-ui_gfx_BUILD.gn | 4 +-
www/iridium/files/patch-ui_gfx_gpu__fence.cc | 36 ++++
www/iridium/files/patch-ui_gl_gl__switches.cc | 6 +-
...yland_host_wayland__exchange__data__provider.cc | 14 +-
www/iridium/files/patch-ui_views_BUILD.gn | 4 +-
.../patch-ui_views_controls_textfield_textfield.cc | 6 +-
.../files/patch-ui_views_focus_focus__manager.cc | 6 +-
...__aura_desktop__window__tree__host__platform.cc | 8 +-
www/iridium/files/patch-ui_views_widget_widget.cc | 4 +-
www/iridium/files/patch-v8_BUILD.gn | 34 ++--
www/iridium/files/patch-v8_src_api_api.cc | 6 +-
.../files/patch-v8_src_execution_isolate.cc | 6 +-
341 files changed, 1893 insertions(+), 1489 deletions(-)
diff --git a/www/iridium/Makefile b/www/iridium/Makefile
index 2e3692263af6..7bc7b35c5a5f 100644
--- a/www/iridium/Makefile
+++ b/www/iridium/Makefile
@@ -1,5 +1,5 @@
PORTNAME= iridium
-PORTVERSION= 2026.04.146.5
+PORTVERSION= 2026.04.147
PULSEMV= 16
PULSEV= ${PULSEMV}.1
CATEGORIES= www wayland
diff --git a/www/iridium/distinfo b/www/iridium/distinfo
index 227439705999..a9c9cbe5f256 100644
--- a/www/iridium/distinfo
+++ b/www/iridium/distinfo
@@ -1,6 +1,6 @@
-TIMESTAMP = 1775119021
-SHA256 (iridium-browser-2026.04.146.5.tar.xz) = b82609919c093fbe8d56d7eb69df27eb371514747b7f443fe229a075a22af89d
-SIZE (iridium-browser-2026.04.146.5.tar.xz) = 1286581800
+TIMESTAMP = 1776255158
+SHA256 (iridium-browser-2026.04.147.tar.xz) = 5e5cd3c84165da2206e4feeff1fdac8d4ae537d2e8b97935dd916c656102f2b1
+SIZE (iridium-browser-2026.04.147.tar.xz) = 1284503020
SHA256 (pulseaudio-16.1.tar.gz) = 027266c62f2a84422ac45fa721a649508f0f1628fb1fd9242315ac54ce2d7c92
SIZE (pulseaudio-16.1.tar.gz) = 2763111
SHA256 (rust/crates/Inflector-0.11.4.crate) = fe438c63458706e03479442743baae6c88256498e6431708f6dfc520a26515d3
diff --git a/www/iridium/files/patch-base_BUILD.gn b/www/iridium/files/patch-base_BUILD.gn
index 303b7f28f2fe..87c58709f6d9 100644
--- a/www/iridium/files/patch-base_BUILD.gn
+++ b/www/iridium/files/patch-base_BUILD.gn
@@ -1,6 +1,6 @@
---- base/BUILD.gn.orig 2026-03-24 16:59:08 UTC
+--- base/BUILD.gn.orig 2026-04-15 12:07:04 UTC
+++ base/BUILD.gn
-@@ -1160,11 +1160,26 @@ component("base") {
+@@ -1163,11 +1163,26 @@ component("base") {
# Needed for <atomic> if using newer C++ library than sysroot, except if
# building inside the cros_sdk environment - use host_toolchain as a
# more robust check for this.
@@ -28,7 +28,7 @@
if (use_allocator_shim) {
if (is_apple) {
sources += [ "allocator/early_zone_registration_apple.h" ]
-@@ -1184,7 +1199,7 @@ component("base") {
+@@ -1187,7 +1202,7 @@ component("base") {
# Allow more direct string conversions on platforms with native utf8
# strings
@@ -103,7 +103,7 @@
(is_win || is_linux || is_android || is_mac)
flags = [ "PROTECTED_MEMORY_ENABLED=$protected_memory_enabled" ]
-@@ -3309,7 +3367,7 @@ if (is_apple) {
+@@ -3310,7 +3368,7 @@ if (is_apple) {
}
}
@@ -112,7 +112,7 @@
# This test must compile with -fstack-protector-all
source_set("stack_canary_linux_unittests") {
testonly = true
-@@ -4052,7 +4110,7 @@ test("base_unittests") {
+@@ -4053,7 +4111,7 @@ test("base_unittests") {
configs += [ ":delayload_esent_dll" ]
}
@@ -121,7 +121,7 @@
sources += [
"debug/proc_maps_linux_unittest.cc",
"files/scoped_file_linux_unittest.cc",
-@@ -4077,7 +4135,7 @@ test("base_unittests") {
+@@ -4078,7 +4136,7 @@ test("base_unittests") {
"posix/file_descriptor_shuffle_unittest.cc",
"posix/unix_domain_socket_unittest.cc",
]
@@ -130,7 +130,7 @@
sources += [
"profiler/stack_base_address_posix_unittest.cc",
"profiler/stack_copier_signal_unittest.cc",
-@@ -4088,7 +4146,7 @@ test("base_unittests") {
+@@ -4089,7 +4147,7 @@ test("base_unittests") {
# Allow more direct string conversions on platforms with native utf8
# strings
@@ -139,7 +139,7 @@
defines += [ "SYSTEM_NATIVE_UTF8" ]
}
-@@ -4275,7 +4333,7 @@ test("base_unittests") {
+@@ -4276,7 +4334,7 @@ test("base_unittests") {
deps += [ ":base_profiler_test_support_library" ]
}
diff --git a/www/iridium/files/patch-base_allocator_partition__allocator_partition__alloc.gni b/www/iridium/files/patch-base_allocator_partition__allocator_partition__alloc.gni
index b59ee87bf163..908641ea01eb 100644
--- a/www/iridium/files/patch-base_allocator_partition__allocator_partition__alloc.gni
+++ b/www/iridium/files/patch-base_allocator_partition__allocator_partition__alloc.gni
@@ -1,4 +1,4 @@
---- base/allocator/partition_allocator/partition_alloc.gni.orig 2026-03-24 16:59:08 UTC
+--- base/allocator/partition_allocator/partition_alloc.gni.orig 2026-04-15 12:07:04 UTC
+++ base/allocator/partition_allocator/partition_alloc.gni
@@ -92,7 +92,7 @@ if (current_cpu == "x64" || current_cpu == "arm64" ||
# TODO(crbug.com/329199197): Clean this up when experiments are complete.
@@ -9,7 +9,7 @@
!is_hwasan && (is_linux || is_android)
declare_args() {
-@@ -500,7 +500,7 @@ assert(!use_asan_backup_ref_ptr || use_raw_ptr_hookabl
+@@ -496,7 +496,7 @@ assert(!use_asan_backup_ref_ptr || use_raw_ptr_hookabl
# dependencies that use partition_allocator are compiled in AOSP against a
# version of glibc that does not include pkeys syscall numbers.
is_pkeys_available =
diff --git a/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_BUILD.gn b/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_BUILD.gn
index 9fbd8e8e0af6..06dadee6fe7a 100644
--- a/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_BUILD.gn
+++ b/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_BUILD.gn
@@ -1,6 +1,6 @@
---- base/allocator/partition_allocator/src/partition_alloc/BUILD.gn.orig 2026-03-24 16:59:08 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/BUILD.gn.orig 2026-04-15 12:07:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/BUILD.gn
-@@ -923,7 +923,7 @@ if (is_clang_or_gcc) {
+@@ -908,7 +908,7 @@ if (is_clang_or_gcc) {
configs -= [ partition_alloc_enable_arc_config ]
}
}
diff --git a/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_address__space__randomization.h b/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_address__space__randomization.h
index 7463fe0ee91a..4bb506693bf0 100644
--- a/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_address__space__randomization.h
+++ b/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_address__space__randomization.h
@@ -1,4 +1,4 @@
---- base/allocator/partition_allocator/src/partition_alloc/address_space_randomization.h.orig 2026-02-16 10:45:29 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/address_space_randomization.h.orig 2026-04-15 12:07:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/address_space_randomization.h
@@ -38,7 +38,7 @@ AslrMask(uintptr_t bits) {
@@ -9,7 +9,7 @@
// We shouldn't allocate system pages at all for sanitizer builds. However,
// we do, and if random hint addresses interfere with address ranges
-@@ -125,7 +125,7 @@ AslrMask(uintptr_t bits) {
+@@ -142,7 +142,7 @@ AslrMask(uintptr_t bits) {
return AslrAddress(0x20000000ULL);
}
#elif PA_BUILDFLAG(PA_ARCH_CPU_ARM64)
diff --git a/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__root.cc b/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__root.cc
index f1b7f574f72d..c5bf626a95ee 100644
--- a/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__root.cc
+++ b/www/iridium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__root.cc
@@ -1,4 +1,4 @@
---- base/allocator/partition_allocator/src/partition_alloc/partition_root.cc.orig 2026-02-16 10:45:29 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/partition_root.cc.orig 2026-04-15 12:07:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/partition_root.cc
@@ -48,7 +48,7 @@
#include "wow64apiset.h"
@@ -9,7 +9,7 @@
#include <pthread.h>
#endif // PA_BUILDFLAG(IS_LINUX) || PA_BUILDFLAG(IS_CHROMEOS)
-@@ -297,7 +297,7 @@ void PartitionAllocMallocInitOnce() {
+@@ -255,7 +255,7 @@ void PartitionAllocMallocInitOnce() {
return;
}
@@ -18,7 +18,7 @@
// When fork() is called, only the current thread continues to execute in the
// child process. If the lock is held, but *not* by this thread when fork() is
// called, we have a deadlock.
-@@ -1007,7 +1007,7 @@ void PartitionRoot::Init(PartitionOptions opts) {
+@@ -973,7 +973,7 @@ void PartitionRoot::Init(PartitionOptions opts) {
// apple OSes.
PA_CHECK((internal::SystemPageSize() == (size_t{1} << 12)) ||
(internal::SystemPageSize() == (size_t{1} << 14)));
diff --git a/www/iridium/files/patch-base_files_file__util__unittest.cc b/www/iridium/files/patch-base_files_file__util__unittest.cc
index a8c8c301fc4c..a5d1de106961 100644
--- a/www/iridium/files/patch-base_files_file__util__unittest.cc
+++ b/www/iridium/files/patch-base_files_file__util__unittest.cc
@@ -1,6 +1,6 @@
---- base/files/file_util_unittest.cc.orig 2025-12-10 15:04:57 UTC
+--- base/files/file_util_unittest.cc.orig 2026-04-15 12:07:04 UTC
+++ base/files/file_util_unittest.cc
-@@ -4156,7 +4156,7 @@ TEST_F(FileUtilTest, ReadFileToStringWithNamedPipe) {
+@@ -4158,7 +4158,7 @@ TEST_F(FileUtilTest, ReadFileToStringWithNamedPipe) {
}
#endif // BUILDFLAG(IS_WIN)
diff --git a/www/iridium/files/patch-base_memory_platform__shared__memory__region.h b/www/iridium/files/patch-base_memory_platform__shared__memory__region.h
index 1adf93984e37..66104afcbf14 100644
--- a/www/iridium/files/patch-base_memory_platform__shared__memory__region.h
+++ b/www/iridium/files/patch-base_memory_platform__shared__memory__region.h
@@ -1,6 +1,6 @@
---- base/memory/platform_shared_memory_region.h.orig 2025-12-10 15:04:57 UTC
+--- base/memory/platform_shared_memory_region.h.orig 2026-04-15 12:07:04 UTC
+++ base/memory/platform_shared_memory_region.h
-@@ -99,7 +99,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
+@@ -104,7 +104,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
#if BUILDFLAG(IS_FUCHSIA)
kNotVmo,
#endif
@@ -9,7 +9,7 @@
kFcntlFailed,
kReadOnlyFdNotReadOnly,
kUnexpectedReadOnlyFd,
-@@ -230,7 +230,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
+@@ -249,7 +249,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
CheckPlatformHandlePermissionsCorrespondToMode);
static PlatformSharedMemoryRegion Create(Mode mode,
size_t size
diff --git a/www/iridium/files/patch-base_threading_platform__thread.h b/www/iridium/files/patch-base_threading_platform__thread.h
index b6a0508ae924..31341387214a 100644
--- a/www/iridium/files/patch-base_threading_platform__thread.h
+++ b/www/iridium/files/patch-base_threading_platform__thread.h
@@ -1,6 +1,6 @@
---- base/threading/platform_thread.h.orig 2026-03-24 16:59:08 UTC
+--- base/threading/platform_thread.h.orig 2026-04-15 12:07:04 UTC
+++ base/threading/platform_thread.h
-@@ -61,6 +61,8 @@ class BASE_EXPORT PlatformThreadId {
+@@ -67,6 +67,8 @@ class BASE_EXPORT PlatformThreadId {
using UnderlyingType = zx_koid_t;
#elif BUILDFLAG(IS_APPLE)
using UnderlyingType = uint64_t;
diff --git a/www/iridium/files/patch-base_threading_platform__thread__unittest.cc b/www/iridium/files/patch-base_threading_platform__thread__unittest.cc
index c49f4ab63e87..008bad9d1770 100644
--- a/www/iridium/files/patch-base_threading_platform__thread__unittest.cc
+++ b/www/iridium/files/patch-base_threading_platform__thread__unittest.cc
@@ -1,6 +1,6 @@
---- base/threading/platform_thread_unittest.cc.orig 2026-02-16 10:45:29 UTC
+--- base/threading/platform_thread_unittest.cc.orig 2026-04-15 12:07:04 UTC
+++ base/threading/platform_thread_unittest.cc
-@@ -36,7 +36,7 @@
+@@ -67,7 +67,7 @@ std::ostream& operator<<(std::ostream& os, MessagePump
#include "base/time/time.h"
#endif
@@ -9,7 +9,7 @@
#include <pthread.h>
#include <sys/syscall.h>
#include <sys/types.h>
-@@ -374,7 +374,7 @@ TEST(PlatformThreadTest,
+@@ -408,7 +408,7 @@ TEST(PlatformThreadTest,
// and hardcodes what we know. Please inform scheduler-dev@chromium.org if this
// proprerty changes for a given platform.
TEST(PlatformThreadTest, CanChangeThreadType) {
@@ -18,7 +18,7 @@
// On Ubuntu, RLIMIT_NICE and RLIMIT_RTPRIO are 0 by default, so we won't be
// able to increase priority to any level unless we are root (euid == 0).
bool kCanIncreasePriority = false;
-@@ -622,12 +622,16 @@ INSTANTIATE_TEST_SUITE_P(
+@@ -656,12 +656,16 @@ INSTANTIATE_TEST_SUITE_P(
#endif // BUILDFLAG(IS_APPLE)
diff --git a/www/iridium/files/patch-base_trace__event_malloc__dump__provider.cc b/www/iridium/files/patch-base_trace__event_malloc__dump__provider.cc
index 6b1ebc6c9c37..1469265e214b 100644
--- a/www/iridium/files/patch-base_trace__event_malloc__dump__provider.cc
+++ b/www/iridium/files/patch-base_trace__event_malloc__dump__provider.cc
@@ -1,6 +1,6 @@
---- base/trace_event/malloc_dump_provider.cc.orig 2026-02-16 10:45:29 UTC
+--- base/trace_event/malloc_dump_provider.cc.orig 2026-04-15 12:07:04 UTC
+++ base/trace_event/malloc_dump_provider.cc
-@@ -27,6 +27,8 @@
+@@ -28,6 +28,8 @@
#if BUILDFLAG(IS_APPLE)
#include <malloc/malloc.h>
@@ -9,7 +9,7 @@
#else
#include <malloc.h>
#endif
-@@ -176,7 +178,7 @@ void ReportAppleAllocStats(size_t* total_virtual_size,
+@@ -192,7 +194,7 @@ void ReportAppleAllocStats(size_t* total_virtual_size,
#if (PA_BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC) && BUILDFLAG(IS_ANDROID)) || \
(!PA_BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC) && !BUILDFLAG(IS_WIN) && \
@@ -18,7 +18,7 @@
void ReportMallinfoStats(ProcessMemoryDump* pmd,
size_t* total_virtual_size,
size_t* resident_size,
-@@ -379,6 +381,9 @@ bool MallocDumpProvider::OnMemoryDump(const MemoryDump
+@@ -395,6 +397,9 @@ bool MallocDumpProvider::OnMemoryDump(const MemoryDump
&allocated_objects_count);
#elif BUILDFLAG(IS_FUCHSIA)
// TODO(fuchsia): Port, see https://crbug.com/706592.
diff --git a/www/iridium/files/patch-base_trace__event_memory__dump__manager.cc b/www/iridium/files/patch-base_trace__event_memory__dump__manager.cc
index eef370d92592..975e1543178a 100644
--- a/www/iridium/files/patch-base_trace__event_memory__dump__manager.cc
+++ b/www/iridium/files/patch-base_trace__event_memory__dump__manager.cc
@@ -1,6 +1,6 @@
---- base/trace_event/memory_dump_manager.cc.orig 2026-03-24 16:59:08 UTC
+--- base/trace_event/memory_dump_manager.cc.orig 2026-04-15 12:07:04 UTC
+++ base/trace_event/memory_dump_manager.cc
-@@ -95,7 +95,7 @@ const char* const MemoryDumpManager::kSystemAllocatorP
+@@ -96,7 +96,7 @@ const char* const MemoryDumpManager::kSystemAllocatorP
#if defined(MALLOC_MEMORY_TRACING_SUPPORTED)
MallocDumpProvider::kAllocatedObjects;
#else
diff --git a/www/iridium/files/patch-build_config_clang_BUILD.gn b/www/iridium/files/patch-build_config_clang_BUILD.gn
index 885eb46a2014..516ba7b3b2d6 100644
--- a/www/iridium/files/patch-build_config_clang_BUILD.gn
+++ b/www/iridium/files/patch-build_config_clang_BUILD.gn
@@ -1,6 +1,6 @@
---- build/config/clang/BUILD.gn.orig 2026-03-24 16:59:08 UTC
+--- build/config/clang/BUILD.gn.orig 2026-04-15 12:07:04 UTC
+++ build/config/clang/BUILD.gn
-@@ -237,7 +237,12 @@ template("clang_lib") {
+@@ -240,7 +240,12 @@ template("clang_lib") {
# Adds a dependency on the Clang runtime library clang_rt.builtins.
clang_lib("compiler_builtins") {
diff --git a/www/iridium/files/patch-build_config_compiler_BUILD.gn b/www/iridium/files/patch-build_config_compiler_BUILD.gn
index 6221a765517a..d88453a5c4a0 100644
--- a/www/iridium/files/patch-build_config_compiler_BUILD.gn
+++ b/www/iridium/files/patch-build_config_compiler_BUILD.gn
@@ -1,4 +1,4 @@
---- build/config/compiler/BUILD.gn.orig 2026-03-24 16:59:08 UTC
+--- build/config/compiler/BUILD.gn.orig 2026-04-15 12:07:04 UTC
+++ build/config/compiler/BUILD.gn
@@ -202,7 +202,7 @@ declare_args() {
# This greatly reduces the size of debug builds, at the cost of
@@ -36,7 +36,7 @@
}
# compiler ---------------------------------------------------------------------
-@@ -589,6 +592,10 @@ config("compiler") {
+@@ -548,6 +551,10 @@ config("compiler") {
}
}
@@ -46,9 +46,9 @@
+
# Linux-specific compiler flags setup.
# ------------------------------------
- if (use_icf && (!is_apple || use_lld)) {
-@@ -679,7 +686,7 @@ config("compiler") {
- ldflags += [ "-Wl,-z,keep-text-section-prefix" ]
+ if (is_linux || is_chromeos) {
+@@ -604,7 +611,7 @@ config("compiler") {
+ }
}
- if (is_clang) {
@@ -56,7 +56,7 @@
cflags += [ "-fcrash-diagnostics-dir=" + clang_diagnostic_dir ]
if (save_reproducers_on_lld_crash && use_lld) {
ldflags += [
-@@ -1288,7 +1295,7 @@ config("compiler_cpu_abi") {
+@@ -1313,7 +1320,7 @@ config("compiler_cpu_abi") {
# CPU architecture. We may or may not be doing a cross compile now, so for
# simplicity we always explicitly set the architecture.
if (current_cpu == "x64") {
@@ -65,7 +65,7 @@
cflags += [ "--target=x86_64-unknown-linux-gnu" ]
ldflags += [ "--target=x86_64-unknown-linux-gnu" ]
} else {
-@@ -1302,7 +1309,7 @@ config("compiler_cpu_abi") {
+@@ -1327,7 +1334,7 @@ config("compiler_cpu_abi") {
ldflags += [ "-march=$cros_target_cpu_arch" ]
}
} else if (current_cpu == "x86") {
@@ -74,7 +74,7 @@
cflags += [ "--target=i386-unknown-linux-gnu" ]
ldflags += [ "--target=i386-unknown-linux-gnu" ]
} else {
-@@ -1314,7 +1321,7 @@ config("compiler_cpu_abi") {
+@@ -1339,7 +1346,7 @@ config("compiler_cpu_abi") {
"-msse3",
]
} else if (current_cpu == "arm") {
@@ -83,7 +83,7 @@
cflags += [ "--target=arm-linux-gnueabihf" ]
ldflags += [ "--target=arm-linux-gnueabihf" ]
}
-@@ -1323,7 +1330,7 @@ config("compiler_cpu_abi") {
+@@ -1348,7 +1355,7 @@ config("compiler_cpu_abi") {
"-mfloat-abi=$arm_float_abi",
]
} else if (current_cpu == "arm64") {
@@ -92,7 +92,7 @@
cflags += [ "--target=aarch64-linux-gnu" ]
ldflags += [ "--target=aarch64-linux-gnu" ]
}
-@@ -1735,7 +1742,7 @@ config("compiler_deterministic") {
+@@ -1760,7 +1767,7 @@ config("compiler_deterministic") {
}
config("clang_revision") {
@@ -101,7 +101,7 @@
current_os != "zos") {
_perform_consistency_checks = current_toolchain == default_toolchain
if (llvm_force_head_revision) {
-@@ -1860,13 +1867,13 @@ config("sanitize_c_array_bounds") {
+@@ -1885,13 +1892,13 @@ config("sanitize_c_array_bounds") {
# sanitizer) is enabled, they then do expensive debug like operations. We
# want to suppress this behaviour since we want to keep performance costs
# as low as possible while having these checks.
@@ -117,7 +117,7 @@
]
}
}
-@@ -2980,7 +2987,7 @@ config("afdo_optimize_size") {
+@@ -3032,7 +3039,7 @@ config("afdo_optimize_size") {
# There are some targeted places that AFDO regresses, so we provide a separate
# config to allow AFDO to be disabled per-target.
config("afdo") {
@@ -126,7 +126,7 @@
cflags = []
if (clang_emit_debug_info_for_profiling) {
# Add the following flags to generate debug info for profiling.
-@@ -3007,7 +3014,7 @@ config("afdo") {
+@@ -3059,7 +3066,7 @@ config("afdo") {
cflags += [ "-Wno-backend-plugin" ]
inputs = [ _clang_sample_profile ]
}
diff --git a/www/iridium/files/patch-build_dotfile__settings.gni b/www/iridium/files/patch-build_dotfile__settings.gni
index d1156f782609..9330cc85aab8 100644
--- a/www/iridium/files/patch-build_dotfile__settings.gni
+++ b/www/iridium/files/patch-build_dotfile__settings.gni
@@ -1,6 +1,6 @@
---- build/dotfile_settings.gni.orig 2025-12-10 15:04:57 UTC
+--- build/dotfile_settings.gni.orig 2026-04-15 12:07:04 UTC
+++ build/dotfile_settings.gni
-@@ -23,6 +23,7 @@ build_dotfile_settings = {
+@@ -24,6 +24,7 @@ build_dotfile_settings = {
"//build/config/mac/mac_sdk.gni",
"//build/config/mac/rules.gni",
"//build/config/posix/BUILD.gn",
diff --git a/www/iridium/files/patch-build_rust_std_BUILD.gn b/www/iridium/files/patch-build_rust_std_BUILD.gn
index f360ec81b1ad..7e17c4fc4ed3 100644
--- a/www/iridium/files/patch-build_rust_std_BUILD.gn
+++ b/www/iridium/files/patch-build_rust_std_BUILD.gn
@@ -1,6 +1,6 @@
---- build/rust/std/BUILD.gn.orig 2026-01-16 14:21:21 UTC
+--- build/rust/std/BUILD.gn.orig 2026-04-15 12:07:04 UTC
+++ build/rust/std/BUILD.gn
-@@ -79,7 +79,6 @@ if (toolchain_has_rust) {
+@@ -78,7 +78,6 @@ if (toolchain_has_rust) {
# don't need to pass to the C++ linker because they're used for specialized
# purposes.
skip_stdlib_files = [
diff --git a/www/iridium/files/patch-cc_base_features.cc b/www/iridium/files/patch-cc_base_features.cc
index d07210c22e45..f929cd579751 100644
--- a/www/iridium/files/patch-cc_base_features.cc
+++ b/www/iridium/files/patch-cc_base_features.cc
@@ -1,6 +1,6 @@
---- cc/base/features.cc.orig 2025-12-10 15:04:57 UTC
+--- cc/base/features.cc.orig 2026-04-15 12:07:04 UTC
+++ cc/base/features.cc
-@@ -42,7 +42,7 @@ const base::FeatureParam<int> kDeferImplInvalidationFr
+@@ -37,7 +37,7 @@ const base::FeatureParam<int> kDeferImplInvalidationFr
// Note that kUseDMSAAForTiles only controls vulkan launch on android. We will
// be using a separate flag to control the launch on GL.
BASE_FEATURE(kUseDMSAAForTiles,
diff --git a/www/iridium/files/patch-chrome_app_chrome__main__delegate.cc b/www/iridium/files/patch-chrome_app_chrome__main__delegate.cc
index 324c3524ccbc..51e8d6e4bec9 100644
--- a/www/iridium/files/patch-chrome_app_chrome__main__delegate.cc
+++ b/www/iridium/files/patch-chrome_app_chrome__main__delegate.cc
@@ -1,6 +1,6 @@
---- chrome/app/chrome_main_delegate.cc.orig 2026-03-24 16:59:08 UTC
+--- chrome/app/chrome_main_delegate.cc.orig 2026-04-15 12:07:04 UTC
+++ chrome/app/chrome_main_delegate.cc
-@@ -102,7 +102,7 @@
+@@ -103,7 +103,7 @@
#include "ui/base/ui_base_switches.h"
#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS) || \
@@ -9,7 +9,7 @@
#include "components/webapps/isolated_web_apps/scheme.h"
#endif
-@@ -182,17 +182,17 @@
+@@ -184,17 +184,17 @@
#include "v8/include/v8.h"
#endif
@@ -30,7 +30,7 @@
#include "chrome/browser/policy/policy_path_parser.h"
#include "components/crash/core/app/crashpad.h"
#endif
-@@ -226,7 +226,7 @@ const char* const ChromeMainDelegate::kNonWildcardDoma
+@@ -228,7 +228,7 @@ const char* const ChromeMainDelegate::kNonWildcardDoma
#endif
chrome::kChromeSearchScheme,
#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS) || \
@@ -39,7 +39,7 @@
webapps::kIsolatedAppScheme,
#endif
content::kChromeDevToolsScheme, content::kChromeUIScheme,
-@@ -301,7 +301,7 @@ void AdjustLinuxOOMScore(const std::string& process_ty
+@@ -303,7 +303,7 @@ void AdjustLinuxOOMScore(const std::string& process_ty
// and resources loaded.
bool SubprocessNeedsResourceBundle(const std::string& process_type) {
return
@@ -48,7 +48,7 @@
// The zygote process opens the resources for the renderers.
process_type == switches::kZygoteProcess ||
#endif
-@@ -381,7 +381,7 @@ bool HandleVersionSwitches(const base::CommandLine& co
+@@ -383,7 +383,7 @@ bool HandleVersionSwitches(const base::CommandLine& co
return false;
}
@@ -57,7 +57,7 @@
// Show the man page if --help or -h is on the command line.
void HandleHelpSwitches(const base::CommandLine& command_line) {
if (command_line.HasSwitch(switches::kHelp) ||
-@@ -393,7 +393,7 @@ void HandleHelpSwitches(const base::CommandLine& comma
+@@ -395,7 +395,7 @@ void HandleHelpSwitches(const base::CommandLine& comma
}
#endif // BUILDFLAG(IS_LINUX)
@@ -66,7 +66,7 @@
void SIGTERMProfilingShutdown(int signal) {
content::Profiling::Stop();
struct sigaction sigact;
-@@ -475,7 +475,7 @@ std::optional<int> AcquireProcessSingleton(
+@@ -477,7 +477,7 @@ std::optional<int> AcquireProcessSingleton(
// process can be exited.
ChromeProcessSingleton::CreateInstance(user_data_dir);
@@ -75,7 +75,7 @@
// Read the xdg-activation token and set it in the command line for the
// duration of the notification in order to ensure this is propagated to an
// already running browser process if it exists.
-@@ -553,7 +553,7 @@ void InitializeUserDataDir(base::CommandLine* command_
+@@ -555,7 +555,7 @@ void InitializeUserDataDir(base::CommandLine* command_
std::string process_type =
command_line->GetSwitchValueASCII(switches::kProcessType);
@@ -84,7 +84,7 @@
// On Linux, Chrome does not support running multiple copies under different
// DISPLAYs, so the profile directory can be specified in the environment to
// support the virtual desktop use-case.
-@@ -659,7 +659,7 @@ void RecordMainStartupMetrics(const StartupTimestamps&
+@@ -661,7 +661,7 @@ void RecordMainStartupMetrics(const StartupTimestamps&
#endif
#if BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN) || BUILDFLAG(IS_LINUX) || \
@@ -93,7 +93,7 @@
// Record the startup process creation time on supported platforms. On Android
// this is recorded in ChromeMainDelegateAndroid.
startup_metric_utils::GetCommon().RecordStartupProcessCreationTime(
-@@ -821,7 +821,7 @@ std::optional<int> ChromeMainDelegate::PostEarlyInitia
+@@ -831,7 +831,7 @@ std::optional<int> ChromeMainDelegate::PostEarlyInitia
#if BUILDFLAG(IS_OZONE)
// Initialize Ozone platform and add required feature flags as per platform's
// properties.
@@ -102,16 +102,7 @@
ui::SetOzonePlatformForLinuxIfNeeded(*base::CommandLine::ForCurrentProcess());
#endif
ui::OzonePlatform::PreEarlyInitialization();
-@@ -983,7 +983,7 @@ void ChromeMainDelegate::CommonEarlyInitialization() {
-
- const bool emit_crashes =
- #if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_MAC) || \
-- BUILDFLAG(IS_WIN)
-+ BUILDFLAG(IS_WIN) || BUILDFLAG(IS_BSD)
- IsCanaryDev();
- #else
- false;
-@@ -1125,7 +1125,7 @@ std::optional<int> ChromeMainDelegate::BasicStartupCom
+@@ -1127,7 +1127,7 @@ std::optional<int> ChromeMainDelegate::BasicStartupCom
return 0; // Got a --credits switch; exit with a success error code.
}
@@ -120,7 +111,7 @@
// This will directly exit if the user asked for help.
HandleHelpSwitches(command_line);
#endif
-@@ -1441,7 +1441,7 @@ void ChromeMainDelegate::PreSandboxStartup() {
+@@ -1457,7 +1457,7 @@ void ChromeMainDelegate::PreSandboxStartup() {
CHECK(!loaded_locale.empty()) << "Locale could not be found for " << locale;
}
diff --git a/www/iridium/files/patch-chrome_browser_BUILD.gn b/www/iridium/files/patch-chrome_browser_BUILD.gn
index b60bdb82ecd2..c1e336478741 100644
--- a/www/iridium/files/patch-chrome_browser_BUILD.gn
+++ b/www/iridium/files/patch-chrome_browser_BUILD.gn
@@ -1,6 +1,6 @@
---- chrome/browser/BUILD.gn.orig 2026-03-30 11:37:05 UTC
+--- chrome/browser/BUILD.gn.orig 2026-04-15 12:07:04 UTC
+++ chrome/browser/BUILD.gn
-@@ -7069,6 +7069,13 @@ static_library("browser") {
+@@ -6927,6 +6927,13 @@ static_library("browser") {
[ "//third_party/webrtc/modules/desktop_capture:pipewire_config" ]
}
diff --git a/www/iridium/files/patch-chrome_browser_about__flags.cc b/www/iridium/files/patch-chrome_browser_about__flags.cc
index 8e4663a0d6c0..1dc8290a9366 100644
--- a/www/iridium/files/patch-chrome_browser_about__flags.cc
+++ b/www/iridium/files/patch-chrome_browser_about__flags.cc
@@ -1,6 +1,6 @@
---- chrome/browser/about_flags.cc.orig 2026-04-02 08:38:27 UTC
+--- chrome/browser/about_flags.cc.orig 2026-04-15 12:07:04 UTC
+++ chrome/browser/about_flags.cc
-@@ -332,13 +332,13 @@
+@@ -337,13 +337,13 @@
#include "components/stylus_handwriting/win/features.h"
#endif
@@ -13,19 +13,28 @@
#if BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || \
- BUILDFLAG(IS_WIN)
+ BUILDFLAG(IS_WIN) || BUILDFLAG(IS_BSD)
- #include "chrome/browser/contextual_cueing/contextual_cueing_features.h" // nogncheck
#include "chrome/browser/enterprise/data_protection/data_protection_features.h"
#include "chrome/browser/enterprise/profile_management/profile_management_features.h"
-@@ -355,7 +355,7 @@
+ #include "chrome/browser/enterprise/webstore/features.h"
+@@ -352,7 +352,7 @@
+ // BUILDFLAG(IS_WIN)
+
+ #if BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || \
+- BUILDFLAG(IS_WIN) || BUILDFLAG(IS_ANDROID)
++ BUILDFLAG(IS_WIN) || BUILDFLAG(IS_ANDROID) || BUILDFLAG(IS_BSD)
+ #include "chrome/browser/contextual_cueing/contextual_cueing_features.h" // nogncheck
+ #endif // BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) ||
+ // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_ANDROID)
+@@ -365,7 +365,7 @@
#include "components/enterprise/platform_auth/platform_auth_features.h"
#endif
-#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN)
+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN) || BUILDFLAG(IS_BSD)
- #include "chrome/browser/enterprise/reporting/reporting_features.h"
+ #include "components/enterprise/browser/reporting/reporting_features.h"
#endif // BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN)
-@@ -788,6 +788,23 @@ const FeatureEntry::FeatureVariation
+@@ -831,6 +831,23 @@ const FeatureEntry::FeatureVariation
"identity request to Android OS",
kWebIdentityDigitalIdentityCredentialHighRiskDialogParam, nullptr}};
*** 10081 LINES SKIPPED ***